@@ -47,8 +47,12 @@ EOF
         $ssh_cmd systemctl restart NetworkManager
     fi
 elif [ "$NETWORK_DRIVER" = "flannel" ]; then
-    $ssh_cmd modprobe vxlan
-    echo "vxlan" > /etc/modules-load.d/vxlan.conf
+    $ssh_cmd modprobe -a vxlan br_netfilter
+    cat <<EOF > /etc/modules-load.d/flannel.conf
+vxlan
+br_netfilter
+EOF
+
 fi
 
 mkdir -p /srv/magnum/kubernetes/
@@ -85,7 +89,7 @@ ExecStart=/bin/bash -c '/usr/bin/podman run --name kubelet \\
     --pid host \\
     --network host \\
     --entrypoint /hyperkube \\
-    --volume /:/rootfs:ro \\
+    --volume /:/rootfs:rslave,ro \\
     --volume /etc/cni/net.d:/etc/cni/net.d:ro,z \\
     --volume /etc/kubernetes:/etc/kubernetes:ro,z \\
     --volume /usr/lib/os-release:/usr/lib/os-release:ro \\
